## Description
[KLayout](https://www.klayout.de/) is an opensource and powerful mask design software. Thanks to its Ruby and Python APIs, programming extensions are available to the users. KlayOut mAsk Layout Automation (KOALA) simplifies the creation of new mask layouts by providing a higher-level interface and easy-to-use, pre-implemented designs.

You will find the installation instructions below and a variety of examples to get you started! 

## How does KLayout work

## Installation
- Download and install [Anaconda](https://www.anaconda.com/)
- Open the Anaconda Prompt (Anaconda3)
- Create a new environment specific for KOALA (for example, naming it "koala") by typing `conda create --name koala` and accept by typing `y`
- Type `conda activate koala` to make the new environment active
- Type `pip install koala` to install KOALA and all its dependencies

- Install a Integrated Development Environment (IDE) for python. We recommend you to install the community version of [PyCharm](https://www.jetbrains.com/pycharm/download/#section=windows).
- Open PyCharm, click at the bottom right to change your interpreter, and click on `Add interpreter`
- On the menu, click on `Conda Environment` and select the recently created KOALA environment. Your interpreter is now the one from the KOALA environment

## Roadmap
- [ ] Implementation of the basic classes
- [ ] Implementation of useful mask elements
- [ ] 3 basic examples
- [ ] 3 advanced examples

## Contributing
This repository has been created by Imke Krauhausen and Charles-Théophile Coen. We are responsible for the development and maintenance of KOALA. If you wish to contribute, please contact us by email!

## Project status
![25%](https://progress-bar.dev/25) Setting up gitlab
